@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -35,21 +35,29 @@
 #ifndef _D_RECOVERABLE_EXCEPTION_H_
 #define _D_RECOVERABLE_EXCEPTION_H_
 #include "Exception.h"
+#include "DownloadResultCode.h"
 
 namespace aria2 {
 
 class RecoverableException:public Exception {
+private:
+  downloadresultcode::RESULT code_;
+
 protected:
-  virtual SharedHandle<Exception> copy() const
-  {
-    SharedHandle<Exception> e(new RecoverableException(*this));
-    return e;
-  }
+  virtual SharedHandle<Exception> copy() const;
 public:
-  RecoverableException(const std::string& msg):Exception(msg) {}
-  RecoverableException(const std::string& msg,
-		       const Exception& cause):Exception(msg, cause) {}
-  RecoverableException(const RecoverableException& e):Exception(e) {}
+  RecoverableException(const char* file, int line, const std::string& msg);
+
+  RecoverableException(const char* file, int line, const std::string& msg,
+                       const Exception& cause);
+
+  RecoverableException(const char* file, int line,
+                       const RecoverableException& e);
+  
+  RecoverableException(const char* file, int line, const std::string& msg,
+                       downloadresultcode::RESULT result);
+
+  downloadresultcode::RESULT getCode() const { return code_; }
 };
 
 } // namespace aria2
