@@ -42,7 +42,7 @@ void BtRegistryTest::testGetDownloadContext()
   CPPUNIT_ASSERT(btRegistry.getDownloadContext(1).isNull());
   SharedHandle<DownloadContext> dctx(new DownloadContext());
   BtObject btObject;
-  btObject._downloadContext = dctx;
+  btObject.downloadContext_ = dctx;
   btRegistry.put(1, btObject);
   CPPUNIT_ASSERT_EQUAL(dctx.get(), btRegistry.getDownloadContext(1).get());
 }
@@ -52,9 +52,9 @@ static void addTwoDownloadContext(BtRegistry& btRegistry)
   SharedHandle<DownloadContext> dctx1(new DownloadContext());
   SharedHandle<DownloadContext> dctx2(new DownloadContext());
   BtObject btObject1;
-  btObject1._downloadContext = dctx1;
+  btObject1.downloadContext_ = dctx1;
   BtObject btObject2;
-  btObject2._downloadContext = dctx2;
+  btObject2.downloadContext_ = dctx2;
   btRegistry.put(1, btObject1);
   btRegistry.put(2, btObject2);
 }
@@ -63,10 +63,10 @@ void BtRegistryTest::testGetDownloadContext_infoHash()
 {
   BtRegistry btRegistry;
   addTwoDownloadContext(btRegistry);
-  BDE attrs1 = BDE::dict();
-  attrs1[bittorrent::INFO_HASH] = std::string("hash1");
-  BDE attrs2 = BDE::dict();
-  attrs2[bittorrent::INFO_HASH] = std::string("hash2");
+  SharedHandle<TorrentAttribute> attrs1(new TorrentAttribute());
+  attrs1->infoHash = "hash1";
+  SharedHandle<TorrentAttribute> attrs2(new TorrentAttribute());
+  attrs2->infoHash = "hash2";
   btRegistry.getDownloadContext(1)->setAttribute
     (bittorrent::BITTORRENT, attrs1);
   btRegistry.getDownloadContext(2)->setAttribute
@@ -74,7 +74,7 @@ void BtRegistryTest::testGetDownloadContext_infoHash()
 
   CPPUNIT_ASSERT(!btRegistry.getDownloadContext("hash1").isNull());
   CPPUNIT_ASSERT(btRegistry.getDownloadContext("hash1").get() ==
-		 btRegistry.getDownloadContext(1).get());
+                 btRegistry.getDownloadContext(1).get());
   CPPUNIT_ASSERT(btRegistry.getDownloadContext("not exists").isNull());
 }
 
